/*  Copyright (C) 2010-2023 Institute of Aerospace Systems, RWTH Aachen
   University - All rights reserved. This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
/**
 * @file hull_surface.h
 * @author Sebastian Oberschwendtner (sebastian.oberschwendtner@tum.de)
 * @brief Factory for surfaces with airfoil sections.
 * @version 2.1.0
 * @date 2023-07-17
 */

#ifndef AIRCRAFTGEOMETRY2_INCLUDE_AIRCRAFTGEOMETRY2_HULL_SURFACE_H_
#define AIRCRAFTGEOMETRY2_INCLUDE_AIRCRAFTGEOMETRY2_HULL_SURFACE_H_

/* === Includes === */
#include <filesystem>
#include "aircraftGeometry2/geometry/factory.h"

namespace geom2
{
    /* === Classes === */
    /**
     * @class HullFactory
     * @brief Factory for hull geometry as defined in the aircraft xml file.
     */
    class HullFactory : public Factory<MultisectionSurface<PolygonSection>>
    {
    public:
        /**
         * @brief Construct a new Factory object
         * 
         * @tparam InputType The input format of the factory.
         * @param input The input data for the factory.
         * @param data_dir The path to the geometry data directory.
         */
        template <typename InputType>
        HullFactory(InputType input, const std::filesystem::path& data_dir) : Factory(input, data_dir) {}

        /**
         * @brief Call the builder of the factory to create a surface.
         * 
         * @param name The identifier of the surface.
         * @return geom2::MultisectionSurface<geom2::PolygonSection> The created surface.
         */
        auto create(std::string_view name) -> MultisectionSurface<PolygonSection> final
        {
            return this->builder->build_hull(name);
        }
    };
}; // namespace geom2

#endif // AIRCRAFTGEOMETRY2_INCLUDE_AIRCRAFTGEOMETRY2_HULL_SURFACE_H_
