/**
 * \file modeSelector.h
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Mode selector of type int from config file
 * \version 0.1
 * \date 2023-10-19
 *
 * @copyright Copyright (c) 2023
 *
 */
#ifndef MODULEBASICS_INCLUDE_MODULEBASICS_MODESELECTOR_H_
#define MODULEBASICS_INCLUDE_MODULEBASICS_MODESELECTOR_H_

#include <map>
#include <string>

/* mode definition */
using modi = unsigned int;

/**
 * \brief Basic selector for modes in control_settings
 *
 */
class Modeselector {
 public:
  /**
   * \brief Construct a new Modeselector object
   *
   * \param mode string values for mode
   */
  explicit Modeselector(const std::string mode) {
    mode_ = mode;
    m_ = selection_[mode_];
  }

  /**
   * \brief Getter method for selected modi
   *
   * \return modi
   */
  modi get_mode_numeric() { return m_; }
  std::string get_mode_string() { return mode_; }

 private:
  modi m_{0};
  std::string mode_{"mode_0"};
  std::map<std::string, modi> selection_{{"mode_0", 0}, {"mode_1", 1}, {"mode_2", 2}, {"mode_3", 3}, {"mode_4", 4},
                                            {"mode_5", 5}, {"mode_6", 6}, {"mode_7", 7}, {"mode_8", 8}, {"mode_9", 9}};
};

#endif  // MODULEBASICS_INCLUDE_MODULEBASICS_MODESELECTOR_H_
